@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This file Copyright (c) 2001 George Lebl
@@ -19,14 +19,14 @@
  */
 
 #include "config.h"
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <locale.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
 #include <string.h>
-
-#include <vicious.h>
+#include <stdio.h>
 
 #include "gdmlanguages.h"
+#include "gdmconfig.h"
 
 typedef struct _Language Language;
 struct _Language {
@@ -78,9 +78,13 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Catalan"), "ca_ES", "Català", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Chinese (simplified)"), "zh_CN", "中文 (简体)", 0 },
+	{ N_("A-M|Chinese (China Mainland)"), "zh_CN", "中文 (中国大陆)", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Chinese (traditional)"), "zh_TW", "中文 (繁體)", 0 },
+	{ N_("A-M|Chinese (Hong Kong)"), "zh_HK", "中文 (香港)", 0 },
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|Chinese (Singapore)"), "zh_SG", "中文 (新加坡)", 0 },
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|Chinese (Taiwan)"), "zh_TW", "中文 (台灣)", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Croatian"), "hr_HR", "Hrvatski", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -90,8 +94,6 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Dutch"), "nl_NL", "Nederlands", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|English"), "en", "English", 0 },
-	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (USA)"), "en_US", "American English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (Australia)"), "en_AU", "Australian English", 0 },
@@ -102,7 +104,7 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (Ireland)"), "en_IE", "Irish English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|English (Denmark)"), "en_IE", "Danish English", 0 },
+	{ N_("A-M|English (Denmark)"), "en_DK", "Danish English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (South Africa)"), "en_ZA", "South African English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -360,6 +362,8 @@ gdm_lang_name (const char *language,
 		return g_strdup (language);
 
 	encoding = strchr (language, '.');
+	if (encoding == NULL)
+	  encoding = strchr (language, '@'); /* treat a modifier without a codeset as an encoding */
 	if (encoding != NULL)
 		encoding++;
 
@@ -374,16 +378,8 @@ gdm_lang_name (const char *language,
 
 	if (lang->untranslated != NULL && untranslated) {
 		char *full;
-		if (markup) {
-			full = g_strdup_printf
-				("%s (%s)",
-				 name,
-				 lang->code,
-				 lang->untranslated);
-		} else {
-			full = g_strdup_printf ("%s (%s)",
-						name, lang->untranslated);
-		}
+		full = g_strdup_printf ("%s (%s)",
+			name, lang->untranslated);
 		g_free (name);
 		name = full;
 	}
@@ -412,13 +408,7 @@ gdm_lang_untranslated_name (const char *language,
 	if (lang == NULL)
 		return NULL;
 
-	if (markup && lang->untranslated != NULL) {
-		return g_strdup_printf ("%s",
-					lang->code,
-					lang->untranslated);
-	} else {
-		return g_strdup (lang->untranslated);
-	}
+	return g_strdup (lang->untranslated);
 }
 
 const char *
@@ -483,6 +473,7 @@ gdm_lang_read_locale_file (const char *locale_file)
 	gboolean clean;
 	char *curlocale;
 	char *getsret;
+	char *p;
 
 	if (locale_file == NULL)
 		return NULL;
@@ -541,8 +532,24 @@ gdm_lang_read_locale_file (const char *locale_file)
 		} else {
 			language = g_new0 (Language, 1);
 			language->found = 1;
-			language->name = g_strdup (name);
-			language->code = g_strdup (lang);
+			/* add a space before an open bracket to match
+			   the style used in the internal list.
+			   e.g. change "English(India)" to "English (India)" */
+			p = strchr (name, '(');
+			if (p != NULL && p > name && *(p-1) != ' ') {
+			  *p = 0;
+			  language->name= g_strconcat (name, " (", p+1, NULL);
+			} else
+			  language->name = g_strdup (name);
+ 			/* only store the "lang_country" part of the locale code, so that we notice
+ 			 * if there is more than one encoding of this language. See bug 132629. */
+			p = strchr (lang, '.');
+ 			if (p == NULL)
+ 			  p = strchr (lang, '@');
+ 			if (p != NULL)
+ 			  language->code = g_strndup (lang, (p - lang));
+ 			else
+ 			  language->code = g_strdup (lang);
 			language->untranslated = NULL;
 			g_hash_table_insert (lang_names,
 					     language->code,
