@@ -21,12 +21,12 @@
 #include <math.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <librsvg/rsvg.h>
-#include "vicious.h"
 
 #include "gdm.h"
 #include "gdmcommon.h"
+#include "gdmconfig.h"
 #include "greeter.h"
 #include "greeter_item.h"
 #include "greeter_events.h"
@@ -131,14 +131,14 @@ static GtkWidget *
 make_menubar (void)
 {
 	GtkWidget *w, *menu;
-	GtkWidget *menubar = gtk_menu_bar_new();
+	GtkWidget *menubar = gtk_menu_bar_new ();
 
 	/* FIXME: add translatable string here */
 	w = gtk_menu_item_new_with_label ("Menu");
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), w);
 	gtk_widget_show (GTK_WIDGET (w));
 
-	menu = gtk_menu_new();
+	menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (w), menu);
 
 	w = gtk_menu_item_new_with_mnemonic (_("Select _Language..."));
@@ -297,7 +297,7 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
 					  NULL);
     break;
   case GREETER_ITEM_TYPE_LABEL:
-    text = greeter_item_expand_text (item->data.text.orig_text);
+    text = gdm_common_expand_text (item->data.text.orig_text);
 
     /* Justification is taken from the anchor */
     if (item->anchor == GTK_ANCHOR_NORTH_WEST ||
@@ -363,9 +363,9 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
     entry = gtk_entry_new ();
     gtk_widget_set_name (entry, "user-pw-entry");
     gtk_entry_set_has_frame (GTK_ENTRY (entry), FALSE);
-    if (GdmUseInvisibleInEntry)
+    if (gdm_config_get_bool (GDM_KEY_ENTRY_INVISIBLE))
       gtk_entry_set_invisible_char (GTK_ENTRY (entry), 0);
-    else if (GdmUseCirclesInEntry)
+    else if (gdm_config_get_bool (GDM_KEY_ENTRY_CIRCLES))
       gtk_entry_set_invisible_char (GTK_ENTRY (entry), 0x25cf);
     gtk_widget_modify_font (entry, item->data.text.fonts[GREETER_ITEM_STATE_NORMAL]);
 
@@ -565,8 +565,12 @@ greeter_canvas_item_break_set_string (GreeterItemInfo *info,
 		gnome_canvas_item_set (GNOME_CANVAS_ITEM (canvas_item), textattr, orig, NULL);
 		pango_layout_get_pixel_size (GNOME_CANVAS_TEXT (canvas_item)->layout, width, height);
 
-		if (real_item != canvas_item)
+		if (real_item != canvas_item) {
 			gtk_object_destroy (GTK_OBJECT (canvas_item));
+			g_string_free (line, TRUE);
+			g_string_free (word, TRUE);
+			g_string_free (str, TRUE);
+		}
 		return;
 	}
 
@@ -579,8 +583,12 @@ greeter_canvas_item_break_set_string (GreeterItemInfo *info,
 			*width = lwidth;
 		if (height != NULL)
 			*height = lheight;
-		if (real_item != canvas_item)
+		if (real_item != canvas_item) {
 			gtk_object_destroy (GTK_OBJECT (canvas_item));
+			g_string_free (line, TRUE);
+			g_string_free (word, TRUE);
+			g_string_free (str, TRUE);
+		}
 		return;
 	}
 
