@@ -1,3 +1,21 @@
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #ifndef GREETER_ITEM_H
 #define GREETER_ITEM_H
 
@@ -37,7 +55,8 @@ enum _GreeterItemSizeType {
   GREETER_ITEM_SIZE_UNSET,
   GREETER_ITEM_SIZE_ABSOLUTE,
   GREETER_ITEM_SIZE_RELATIVE,
-  GREETER_ITEM_SIZE_BOX
+  GREETER_ITEM_SIZE_BOX,
+  GREETER_ITEM_SIZE_SCALE
 };
 
 /* Make sure to adjust the bitfield in the structure if
@@ -71,8 +90,8 @@ struct _GreeterItemInfo {
   float height;
   GreeterItemPosType x_type:2;
   GreeterItemPosType y_type:2;
-  GreeterItemSizeType width_type:2;
-  GreeterItemSizeType height_type:2;
+  GreeterItemSizeType width_type:4;
+  GreeterItemSizeType height_type:4;
   guint x_negative:1; /* needed for -0 */
   guint y_negative:1; /* needed for -0 */
 
@@ -151,6 +170,8 @@ struct _GreeterItemInfo {
 
 #define GREETER_ITEM_TYPE_IS_LIST(info) ((info)->item_type == GREETER_ITEM_TYPE_LIST)
 	  struct {
+		  char *icon_color;
+		  char *label_color;
 		  /* If this is a custom list, then these are the items
 		     to pick from */
 		  GList *items;
